@@ -88,9 +88,9 @@ OUwie<-function(phy,data, model=c("BM1","BMS","OU1","OUM","OUMV","OUMA","OUMVA")
 				edges=edges[sort.list(edges[,3]),]
 				
 				edges[,4]=branch.lengths
-				regime <- matrix(0,nrow=length(edges[,1]),ncol=2)
+				regime <- matrix(0,nrow=length(edges[,1]),ncol=k)
 				regime[,1]<-1
-				regime[,2]<-0
+				regime[,2:k]<-0
 				
 				edges=cbind(edges,regime)
 			}
@@ -182,11 +182,11 @@ OUwie<-function(phy,data, model=c("BM1","BMS","OU1","OUM","OUMV","OUMA","OUMVA")
 	#Likelihood function for estimating model parameters
 	dev<-function(p){
 		
-		Rate.mat[] <- c(p, 0.0000000001)[index.mat]
+		Rate.mat[] <- c(p, 0.00001)[index.mat]
 		N<-length(x[,1])
 		V<-varcov.ou(phy, edges, Rate.mat, root.state=root.state, simmap.tree=simmap.tree)
 		W<-weight.mat(phy, edges, Rate.mat, root.state=root.state, simmap.tree=simmap.tree, assume.station=bool)
-		
+
 		theta<-pseudoinverse(t(W)%*%pseudoinverse(V)%*%W)%*%t(W)%*%pseudoinverse(V)%*%x
 		
 		DET<-determinant(V, logarithm=TRUE)
@@ -200,7 +200,7 @@ OUwie<-function(phy,data, model=c("BM1","BMS","OU1","OUM","OUMV","OUMA","OUMVA")
 	#Informs the user that the optimization routine has started and starting value is being used (default=1)
 	cat("Begin subplex optimization routine -- Starting value:",ip, "\n")
 	
-	lower = rep(0.0000000001, np)
+	lower = rep(0.00001, np)
 	upper = rep(20, np)
 	
 	opts <- list("algorithm"="NLOPT_LN_SBPLX", "maxeval"="1000000", "ftol_rel"=.Machine$double.eps^0.5, "xtol_rel"=.Machine$double.eps^0.5)
@@ -211,7 +211,7 @@ OUwie<-function(phy,data, model=c("BM1","BMS","OU1","OUM","OUMV","OUMA","OUMVA")
 	#Takes estimated parameters from dev and calculates theta for each regime
 	dev.theta<-function(p){
 		
-		Rate.mat[] <- c(p, 0.0000000001)[index.mat]
+		Rate.mat[] <- c(p, 0.00001)[index.mat]
 		
 		N<-length(x[,1])
 		V<-varcov.ou(phy, edges, Rate.mat, root.state=root.state, simmap.tree=simmap.tree)
@@ -329,9 +329,11 @@ OUwie<-function(phy,data, model=c("BM1","BMS","OU1","OUM","OUMV","OUMA","OUMVA")
 		if (any(obj$eigval<0)) {
 			obj$Diagnostic<-'The objective function may be at a saddle point -- check eigenvectors or try a simpler model'
 		}
-		else{obj$Diagnostic<-'Arrived at a reliable solution'
-		}
-	}	
+	}
+	else{
+		obj$Diagnostic<-'Arrived at a reliable solution'
+	}
 	obj
 }
 
+
